ElevenLabsAPI class

Constructors

ElevenLabsAPI()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addVoice(AddVoiceRequest request) Future<String>
Add a new voice Returns the voice ID
deleteHistoryItem(String historyItemId) Future<bool>
Delete a history item Returns true if successful
deleteSample(String voiceId, String sampleId) Future<bool>
Delete a voice sample Returns true if successful
deleteVoice(String voiceId) Future<bool>
Delete a voice Returns true if successful
downloadHistoryItems(List<String> historyItemIds) Future<List<int>>
Download history items Returns a list of bytes
editVoice(String voiceId, EditVoiceRequest request) Future<bool>
Edit a voice Returns true if successful
editVoiceSettings(String voiceId, double similarityBoost, double stability) Future<bool>
Edit settings for a voice Returns true if successful
getCurrentUser() Future<ElevenUser>
Get current user info Returns an ElevenUser object
getCurrentUserSubscription() Future<SubscriptionInfo>
Get current user's subscription info Returns a SubscriptionInfo object
getDefaultVoiceSettings() Future<VoiceSettings>
Get default voice settings Returns a VoiceSettings object
getHistory({int pageSize = 100}) Future<List<HistoryItem>>
Get synthesis history Returns a list of HistoryItem objects
getHistoryItem(String historyItemId) Future<HistoryItem>
Get history item Returns a HistoryItem object
getHistoryItemAudio(String historyItemId) Future<List<int>>
Get audio data for history item Returns a list of bytes
getLanguages() Future<List<Language>>
Get list of languages Returns a list of Language objects
getSampleAudio(String voiceId, String sampleId) Future<List<int>>
Get audio data for a voice sample Returns a list of bytes
getVoice(String voiceId) Future<Voice>
Get voice metadata Returns a Voice object
getVoiceSettings(String voiceId) Future<VoiceSettings>
Get settings for a voice Returns a VoiceSettings object
init({required ElevenLabsConfig config}) Future<void>
Initialize API Takes baseUrl and apiKey as arguments
listVoices() Future<List<Voice>>
List available voices Returns a list of Voice objects
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
synthesize(TextToSpeechRequest request, {int optimizeStreamingLatency = 0}) Future<File>
Synthesize text to speech Takes a TextToSpeechRequest object and a value from 0 to 1 on how much to optimize for streaming latency Returns a HistoryItem object
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited