Feedback class

Feedback JSON Object

Nested within HistoryItem response Contains feedback metadata See ElevenLabs docs for more info

Annotations
  • @JsonSerializable.new()

Constructors

Feedback({required bool audioQuality, required bool emotions, required String feedback, required bool glitches, required bool inaccurateClone, required bool other, required String reviewStatus, required bool thumbsUp})
Feedback.fromJson(Map<String, dynamic> json)
factory

Properties

audioQuality bool
final
emotions bool
final
feedback String
final
glitches bool
final
hashCode int
The hash code for this object.
no setterinherited
inaccurateClone bool
final
other bool
final
reviewStatus String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbsUp bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited