Sharing class

Sharing JSON Object

Nested within Voice response Contains voice sharing metadata See ElevenLabs docs for more info

Annotations
  • @JsonSerializable.new()

Constructors

Sharing({required int clonedByCount, required String historyItemSampleId, required int likedByCount, required String originalVoiceId, required String publicOwnerId, required String status, required String voiceId})
Sharing.fromJson(Map<String, dynamic> json)
factory

Properties

clonedByCount int
final
hashCode int
The hash code for this object.
no setterinherited
historyItemSampleId String
final
likedByCount int
final
originalVoiceId String
final
publicOwnerId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
voiceId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited