SubscriptionInfo class
Subscription Info JSON Object
Returned from /v1/user API endpoints Contains subscription metadata See ElevenLabs docs for more info
- Annotations
-
- @JsonSerializable.new()
Constructors
- SubscriptionInfo({required bool allowedToExtendCharacterLimit, required bool canExtendCharacterLimit, required bool canExtendVoiceLimit, required bool canUseInstantVoiceCloning, required bool canUseProfessionalVoiceCloning, required int characterCount, required int characterLimit, required String currency, required int nextCharacterCountResetUnix, required int professionalVoiceLimit, required String status, required String tier, required int voiceLimit})
-
SubscriptionInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- allowedToExtendCharacterLimit → bool
-
final
- canExtendCharacterLimit → bool
-
final
- canExtendVoiceLimit → bool
-
final
- canUseInstantVoiceCloning → bool
-
final
- canUseProfessionalVoiceCloning → bool
-
final
- characterCount → int
-
final
- characterLimit → int
-
final
- currency → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextCharacterCountResetUnix → int
-
final
- professionalVoiceLimit → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
final
- tier → String
-
final
- voiceLimit → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited