TextToSpeechRequest class
Text to Speech Request JSON Object
Used to make API call to convert text to speech Requires text parameter Can optionally pass modelId and voiceSettings See ElevenLabs docs for more info
- Annotations
-
- @JsonSerializable.new()
Constructors
- TextToSpeechRequest({required String voiceId, String modelId = "eleven_monolingual_v1", required String text, VoiceSettings? voiceSettings})
-
TextToSpeechRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- modelId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
final
- voiceId → String
-
final
- voiceSettings → VoiceSettings?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited