VerificationAttempt class
Verification Attempt JSON Object
Nested within Voice response Contains verification attempt metadata See ElevenLabs docs for more info
- Annotations
-
- @JsonSerializable.new()
Constructors
- VerificationAttempt({required int dateUnix, required num levenshteinDistance, required Recording recording, required num similarity, required String text})
-
VerificationAttempt.fromJson(Map<
String, dynamic> json) -
factory
Properties
- dateUnix → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- levenshteinDistance → num
-
final
- recording → Recording
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- similarity → num
-
final
- text → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited