VoiceSettings class
Voice Settings JSON Object
Requires similarity_boost and stability Both values are 0-1.0, recommended settings are .5 and .75 Check ElevenLabs Docs for more info
- Annotations
-
- @JsonSerializable.new()
Constructors
- VoiceSettings({required double similarityBoost, required double stability})
-
const
-
VoiceSettings.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- similarityBoost → double
-
final
- stability → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited